diff --git a/books/bookvol10.1.pamphlet b/books/bookvol10.1.pamphlet
index 7721582..6741741 100644
--- a/books/bookvol10.1.pamphlet
+++ b/books/bookvol10.1.pamphlet
@@ -8477,6 +8477,68 @@ setCurve(C)$P
 \chapter{Interpolation Formulas}
 {\center{\includegraphics[scale=0.80]{ps/lozenge2.eps}}}
 
+The lozenge diagram is a device for showing that a large number of
+formulas which appear to be different are really all the same. The
+notation for the binomial coefficients
+\[C(u+k,n) = \frac{(u+k)(u+k-1)(u+k-2)\cdots{}(u+k-n+1)}{n!}\]
+There are $n$ factors in the numerator and $n$ in the denominator.
+Viewed as a function of $u$, $C(u+k,n)$ is a polynomial of degree $n$.
+
+The figure above, Hamming \cite{Ham62}
+calls a lozenge diagram. A line starting at
+a point on the left edge and following some path across the page
+defines an interpolation formula if the following rules are used.
+\begin{itemize}
+\item[{\bf 1a}] For a left-to-right step, {\sl add}
+\item[{\bf 1b}] For a right-to-left, {\sl subtract}
+\item[{\bf 2a}] If the {\sl slope} of the step is {\sl positive}, 
+use the product of the difference crossed times the factor 
+immediately {\sl below}.
+\item[{\bf 2b}] If the {\sl slope} of the step is {\sl negative},
+use the product of the difference crossed times the factor
+immediately {\sl above}
+\item[{\bf 3a}] If the step is {\sl horizontal} and passes through a
+{\sl difference}, use the product of the difference times the 
+{\sl average} of the factors {\sl above} and {\sl below}.
+\item[{\bf 3b}] If the step is {\sl horizontal} and passes through a
+{\sl factor}, use the product of the factor times the {\sl average}
+of the differences {\sl above} and {\sl below}.
+\end{itemize}
+
+As an example of rules {\bf 1a} and {\bf 2a}, consider starting at
+$y(0)$ and going down to the right. We get, term by term,
+\[y(u)=y(0)+C(u,1)\Delta{}y(0)+C(u,2)\Delta^2y(0)+C(u,3)\Delta^3y(0)+\cdots\]
+\[=y(0)+u\Delta{}y(0)+\frac{u(u-1)}{2}\Delta^2y(0)+
+\frac{u(u-1)(y-2)}{3!}\Delta^3y(0)+\cdots\]
+which is Newton's formula.
+
+Had we gone up and to the right, we would have used {\bf 1a} and {\bf 2a}
+to get Newton's backward formula:
+\[y(u)=y(0)+C(u,1)\Delta{}y(-1)+C(u+1,2)\Delta^2y(-2)+
+C(u+2,3)\Delta^3y(-3)+\cdots\]
+\[=y(0)+u\Delta{}y(-1)+\frac{(u+1)u}{2}\Delta^2y(-2)+
+\frac{(u+2)(u+1)u}{3!}\Delta^3y(-3)+\cdots\]
+
+To get Stirling's formula, we start at $y(0)$ and go horizontally to
+the right, using rules {\bf 3a} and {\bf 3b}:
+\[y(u)=y(0)
++u\frac{\Delta{}y_0+\Delta{}y_{-1}}{2}
++\frac{C(u+1,2)+C(u,2)}{2}\Delta^2y_{-1}\\
++C(u+1,3)\frac{\Delta^3y_{-2}+\Delta^3y_{-1}}{2}+\cdots\]
+\[=y_0+u\frac{\Delta{}y_0+\Delta{}y_{-1}}{2}
++\frac{u^2}{2}\Delta^2{}y_{-1}
++\frac{u(u^2-1)}{3!}\frac{\Delta^3y_{-2}+\Delta^3y_{-1}}{2}+\cdots\]
+
+If we start midway between $y(0)$ and $y(1)$, we get Bessel's formula:
+\[y(u)=1\frac{y_0+y_1}{2}+\frac{C(u,1)+C(u-1,1)}{2}\Delta{}y_0
++C(u,2)\frac{\Delta^2y_{-1}+\Delta^2y_0}{2}+\cdots\]
+\[=\frac{y_0+y_1}{2}+(u-\frac{1}{2})\Delta{}y_0+
+\frac{u(u-1)}{2}\frac{\Delta^2y_{-1}+\Delta^2y_0}{2}+\cdots\]
+
+If we zigzag properly, we can get Gauss' formula for interpolation:
+\[y(u)=y_0+u\Delta{}y_0+\frac{u(u-1)}{2}\Delta^2y(-1)+
+\frac{u(u^2-1)}{3!}\Delta^3y(-1)+\cdots\]
+
 \chapter{Groebner Basis}
 Groebner Basis
 \chapter{Greatest Common Divisor}
@@ -8564,11 +8626,21 @@ Lecture Notes in Computer Science, vol. 948, 1995, pp. 262--278.
 Th\'ese de doctorat de l'Universit\'e Pierre et Marie Curie (Paris 6), 
 Septembre 1996.
 
+\bibitem[Hamming 62]{Ham62} Hamming R W.\\
+``Numerical Methods for Scientists and Engineers''\\
+Dover (1973) ISBN 0-486-65241-6
+
 \bibitem[Hermite 1872]{Her1872} Hermite, E.\\
 ``Sur l'int\'{e}gration des fractions rationelles.''\\
 {\sl Nouvelles Annales de Math\'{e}matiques}
 ($2^{eme}$ s\'{e}rie), 11:145-148, 1872
 
+\bibitem[van Hoeij 94]{vH94} van Hoeij, M.\\
+``An algorithm for computing an integral basis in an algebraic
+function field''\\
+Journal of Symbolic Computation, 18(4) pp353-363 Oct. 1994
+CODEN JSYCEH ISSN 0747-7171
+
 \bibitem[Le Brigand 88]{LR88} Le Brigand, D.; Risler, J.J.\\
 ``Algorithme de Brill-Noether et codes de Goppa''\\
 Bull. Soc. Math. France, vol. 116, 1988, pp. 231--253.
@@ -8648,12 +8720,6 @@ In {Proceedings of SYMSAC'76} pages 219-226, 1976
 ``On the integration of algebraic functions''\\
 PhD thesis, MIT, Computer Science, 1984
 
-\bibitem[van Hoeij 94]{vH94} van Hoeij, M.\\
-``An algorithm for computing an integral basis in an algebraic
-function field''\\
-Journal of Symbolic Computation, 18(4) pp353-363 Oct. 1994
-CODEN JSYCEH ISSN 0747-7171
-
 \bibitem[Lambov 06]{Lambov06} Lambov, Branimir\\
 ``Interval Arithmetic Using SSE-2''\\
 in Lecture Notes in Computer Science, Springer ISBN 978-3-540-85520-0
diff --git a/books/bookvolbib.pamphlet b/books/bookvolbib.pamphlet
index fd5d673..9e58092 100644
--- a/books/bookvolbib.pamphlet
+++ b/books/bookvolbib.pamphlet
@@ -2854,10 +2854,6 @@ ACM Signum Newsletter. 20, 3 2--25. (1985)
 ``Monte-Carlo Methods''\\
 Methuen. (1967)
 
-\bibitem[Hamming 62]{Ham62} Hamming R W.\\
-``Numerical Methods for Scientists and Engineers''\\
-McGraw-Hill. (1962)
-
 \bibitem[Hathway 1896]{Ha1896} Hathway, Arthur S.\\
 ``A Primer Of Quaternions''\\
 (1896)
@@ -4414,7 +4410,7 @@ techniques for implementing these changes.
 in Lecture Notes in Computer Science, Springer ISBN 978-3-540-85520-0
 (2006) pp102-113
 
-\subsection{Numeric Tests} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\subsection{Numerics} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 \bibitem[Lef\'evre 06]{Lef06} Lef\'evre, Vincent; Stehl\'e, Damien;
 Zimmermann, Paul\\
@@ -4438,6 +4434,10 @@ format and allows the design of reasonably fast routines that will
 evaluate these functions with correct rounding, at least in some situations.
 \end{adjustwidth}
 
+\bibitem[Hamming 62]{Ham62} Hamming R W.\\
+``Numerical Methods for Scientists and Engineers''\\
+Dover (1973) ISBN 0-486-65241-6
+
 \subsection{Advanced Documentation} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 \bibitem [Bostock 14]{Bos14} Bostock, Mike\\
diff --git a/changelog b/changelog
index df21370..86828d5 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20140723 tpd src/axiom-website/patches.html 20140723.01.tpd.patch
+20140723 tpd books/bookvol10.1 expand section on interpolation formulas
+20140723 tpd books/bookvolbib update reference for Ham62
 20140722 tpd src/axiom-website/patches.html 20140722.01.tpd.patch
 20140722 tpd books/bookvol10.1 add section on interpolation formulas
 20140722 tpd books/ps/lozenge2.eps add the Hamming lozenge diagram
diff --git a/patch b/patch
index c155c37..4ccdbe9 100644
--- a/patch
+++ b/patch
@@ -1,3 +1,3 @@
-books/bookvol10.1 add section on interpolation formulas
+books/bookvol10.1, bookvolbib expand section on interpolation formulas
 
 Show a common structure for constructing interpolation formulas.
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index bfc7fd4..664174d 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4558,6 +4558,8 @@ books/bookvol10.1, bookvolbib, bookheader.tex clean up mistakes
 books/bookvol7, bookvol8 apply Camm's patches
 <a href="patches/20140722.01.tpd.patch">20140722.01.tpd.patch</a>
 books/bookvol10.1 add section on interpolation formulas
+<a href="patches/20140723.01.tpd.patch">20140723.01.tpd.patch</a>
+books/bookvol10.1 expand section on interpolation formulas
  </body>
 </html>
 
